﻿using HKLib.Interfaces;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using XExten.Advance.LinqFramework;

namespace HKCardManager.UserPages
{
    public partial class InstitutionalEntryPage : UserControl
    {
        public InstitutionalEntryPage()
        {
            InitializeComponent();
            DataGridViewInit();
            dataGridView1.DataSource = Global.OrgTables;
            this.SizeChanged += InstitutionalEntryPage_SizeChanged;
        }

        private void DataGridViewInit()
        {
            dataGridView1.AllowUserToResizeColumns = false;// 禁止用户改变所有列的列宽 
            dataGridView1.AllowUserToResizeRows = false; //禁止用户改变所有行的行高   
            dataGridView1.ColumnHeadersHeightSizeMode = DataGridViewColumnHeadersHeightSizeMode.DisableResizing;  // 禁止用户改变列头的高度   
            dataGridView1.RowHeadersWidthSizeMode = DataGridViewRowHeadersWidthSizeMode.DisableResizing; // 禁止用户改变列头的宽度   
            dataGridView1.AutoGenerateColumns = false;//禁用自动添加列
            dataGridView1.CellContentClick += DataGridView1_CellContentClick;
        }

        private void DataGridView1_CellContentClick(object? sender, DataGridViewCellEventArgs e)
        {
            int index = dataGridView1.CurrentRow.Index;
            if (index <= dataGridView1.Rows.Count - 1 && dataGridView1.CurrentCell.Value?.ToString() == "删除")
            {
                var res = Global.OrgTables.FirstOrDefault(p => p.Name == dataGridView1.Rows[index].Cells[0].Value?.ToString())?.SId;
                if (string.IsNullOrEmpty(res))
                {
                    MessageLogNotify.GetInstance.ShowError("删除机构失败");
                    return;
                }
                try
                {
                    Task.Factory.StartNew(() =>
                    {
                        if (HKLibHelper.DisableUser(res))
                        {
                            Global.OrgTables.Clear();
                            Global.OrgTables = HKLibHelper.GetOrg();
                            this.Invoke(() =>
                            {
                                dataGridView1.DataSource = null;
                                dataGridView1.DataSource = Global.OrgTables;
                            });
                            MessageLogNotify.GetInstance.Show($"机构：【{dataGridView1.Rows[index].Cells[0].Value?.ToString()}】 删除成功");
                        }
                        else
                            MessageLogNotify.GetInstance.ShowError($"机构：【{dataGridView1.Rows[index].Cells[0].Value?.ToString()}】 删除失败");
                    });
                }
                catch (Exception ex)
                {
                    MessageLogNotify.GetInstance.ShowEx(ex.ToString());
                }
            }
            else if (index <= dataGridView1.Rows.Count - 1 && dataGridView1.CurrentCell.Value?.ToString() == "修改")
            {
                var name = dataGridView1.Rows[index].Cells[0].Value?.ToString();//原名称
                var changeName = dataGridView1.Rows[index].Cells[1].Value?.ToString();//修改后名称
                if (string.IsNullOrEmpty(name))
                {
                    MessageLogNotify.GetInstance.ShowError("原机构名称无效");
                    return;
                }
                if (string.IsNullOrEmpty(changeName))
                {
                    MessageLogNotify.GetInstance.ShowError("请输入新机构名称");
                    return;
                }
                if (name == changeName)
                {
                    MessageLogNotify.GetInstance.ShowError("新名称和旧名称一致，无法修改");
                    return;
                }
                var id = Global.OrgTables.FirstOrDefault(p => p.Name == name)?.SId;
                try
                {
                    Task.Factory.StartNew(() =>
                    {
                        if (HKLibHelper.AlterOrg(changeName, id))
                        {
                            Global.OrgTables.Clear();
                            Global.OrgTables = HKLibHelper.GetOrg();
                            this.Invoke(() =>
                            {
                                dataGridView1.DataSource = null;
                                dataGridView1.DataSource = Global.OrgTables;
                            });
                            MessageLogNotify.GetInstance.Show($"{name} 机构修改成功");
                        }
                        else
                            MessageLogNotify.GetInstance.ShowError($"{name} 机构修改失败");
                    });
                }
                catch (Exception ex)
                {
                    MessageLogNotify.GetInstance.ShowEx(ex.ToString());
                }

            }
        }

        private void InstitutionalEntryPage_SizeChanged(object? sender, EventArgs e)
        {
            this.splitContainer1.SplitterDistance = this.Height - 50;
            //this.panel1.Left = (this.Width - this.panel1.Width) / 2;
            //this.panel1.Top = (this.Height - this.panel1.Height) / 2;
        }

        private void button2_Click(object sender, EventArgs e)
        {
            string name = this.textBox1.Text.Trim();
            if (string.IsNullOrEmpty(name))
            {
                MessageLogNotify.GetInstance.ShowWarning("请输入机构名称");
                return;
            }
            Task.Factory.StartNew(() =>
            {
                this.Invoke(() => { button2.Enabled = false; });
                if (!HKLib.Interfaces.HKLibHelper.SetOrg(name).IsNullOrEmpty())
                {
                    Global.OrgList.Add(name);
                    MessageLogNotify.GetInstance.Show($"【{name}】 机构添加成功");
                }
                else
                    MessageLogNotify.GetInstance.ShowError($"【{name}】 机构添加失败，请重试");
                this.Invoke(() => { button2.Enabled = true; });
            });
        }
    }
}
